<?php
/**
 * Theme functions file
 *
 * Contains all of the Theme's setup functions, custom functions,
 * custom hooks and Theme settings.
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Define Theme Prefix
 */
define( 'PREFIX', 'mymedic-' );

/**
 * Sets the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 *
 * @since 1.0
 */
function mymedic_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'mymedic_content_width', 780 );
	if ( in_array( get_theme_mod( 'theme_layout' ), array( '1c' ) ) ) {
		$GLOBALS['content_width'] = apply_filters( 'mymedic_content_wide_fullwidth', 1170 );
	} elseif ( in_array( get_theme_mod( 'theme_layout' ), array( '1c-n' ) ) ) {
		$GLOBALS['content_width'] = apply_filters( 'mymedic_content_narrow_fullwidth', 975 );
	}
}
add_action( 'after_setup_theme', 'mymedic_content_width', 0 );

if ( ! function_exists( 'mymedic_theme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @since  1.0.0
 */
function mymedic_theme_setup() {

	// Make the theme available for translation.
	load_theme_textdomain( 'mymedic', trailingslashit( get_template_directory() ) . 'languages' );

	// Add custom stylesheet file to the TinyMCE visual editor.
	add_editor_style( array( 'assets/css/editor-style.css', mymedic_fonts_url() ) );

	// Add RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for custom logo.
	 */
	add_theme_support( 'custom-logo', array(
		'height'      => 60,
		'width'       => 215,
		'flex-width'  => true
	) );

	// Enable support for Post Thumbnails.
	add_theme_support( 'post-thumbnails' );

	// used for Blog
	set_post_thumbnail_size( 750, 515, true );

	// Declare image sizes.
	// add_image_size( 'mymedic-widget-thumb', 60, 60, true );
	add_image_size( 'mymedic-doctor', 384, 432, true );
	add_image_size( 'mymedic-square-thumbnail', 150, 150, true );

	// Register custom navigation menu.
	register_nav_menus(
		array(
			'primary'   => __( 'Primary Location', 'mymedic' ),
			'secondary' => __( 'Secondary Location' , 'mymedic' ),
			'footer'    => __( 'Footer Location' , 'mymedic' )
		)
	);

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-list', 'search-form', 'comment-form', 'gallery', 'caption'
	) );

	/*
	 * Enable support for Post Formats.
	 * See: http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'audio', 'image', 'gallery', 'link', 'quote', 'video'
	) );

	// Indicate widget sidebars can use selective refresh in the Customizer.
	add_theme_support( 'customize-selective-refresh-widgets' );

	// Enable theme-layouts extensions.
	add_theme_support( 'theme-layouts',
		array(
			'1c'   => esc_html__( '1 Column Wide (Full Width)', 'mymedic' ),
			'1c-n' => esc_html__( '1 Column Narrow (Full Width)', 'mymedic' ),
			'2c-l' => esc_html__( '2 Columns: Content / Sidebar', 'mymedic' ),
			'2c-r' => esc_html__( '2 Columns: Sidebar / Content', 'mymedic' )
		),
		array( 'customize' => true, 'default' => '2c-l' )
	);

	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );

	// Compatibility with 'Junkie Types' plugin to enable custom post types.
	add_theme_support( 'junkie-doctor' );
	add_theme_support( 'junkie-department' );
	add_theme_support( 'junkie-service' );

}
endif; // mymedic_theme_setup
add_action( 'after_setup_theme', 'mymedic_theme_setup' );

if ( ! function_exists( 'mymedic_reset_default_image_sizes' ) ) :
/**
 * Re-set default image sizes
 *
 * @since  1.0.0
 */
function mymedic_reset_default_image_sizes() {
	// 'large' size: full width
	update_option( 'large_size_w', 1170 );
	update_option( 'large_size_h', 805 );
	update_option( 'large_crop', 1 );

	// 'medium_large' size
	update_option( 'medium_large_size_w', 610 ); // height: 420

	// 'medium' size
	update_option( 'medium_size_w', 385 );
	update_option( 'medium_size_h', 265 );
	update_option( 'medium_crop', 1 );

	// 'thumbnail' size
	update_option( 'thumbnail_size_w', 165 );
	update_option( 'thumbnail_size_h', 110 );
	update_option( 'thumbnail_crop', 1 );
}
endif;
add_action( 'after_switch_theme', 'mymedic_reset_default_image_sizes' );

/**
 * Registers custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function mymedic_widgets_init() {

	// Register ad widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-ads.php';
	register_widget( 'MyMedic_Ads_Widget' );

	// Register Facebook widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-facebook.php';
	register_widget( 'MyMedic_Facebook_Widget' );

	// Register feedburner widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-feedburner.php';
	register_widget( 'MyMedic_Feedburner_Widget' );

	// Register recent posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-recent.php';
	register_widget( 'MyMedic_Recent_Widget' );

	// Register popular posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-popular.php';
	register_widget( 'MyMedic_Popular_Widget' );

	// Register random posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-random.php';
	register_widget( 'MyMedic_Random_Widget' );

	// Register most views posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-views.php';
	register_widget( 'MyMedic_Views_Widget' );

	// Register twitter widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-twitter.php';
	register_widget( 'MyMedic_Twitter_Widget' );

	// Register video widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-video.php';
	register_widget( 'MyMedic_Video_Widget' );

}
add_action( 'widgets_init', 'mymedic_widgets_init' );

/**
 * Registers widget areas and custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function mymedic_sidebars_init() {

	register_sidebar(
		array(
			'name'          => esc_html__( 'Primary Sidebar', 'mymedic' ),
			'id'            => 'primary',
			'description'   => esc_html__( 'Main sidebar that appears on the right/left of content.', 'mymedic' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<div class="widget-title"><h4>',
			'after_title'   => '</h4><hr></div>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 1', 'mymedic' ),
			'id'            => 'footer-1',
			'description'   => esc_html__( 'The footer widget area 1st column.', 'mymedic' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-title"><h4>',
			'after_title'   => '</h4></div>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 2', 'mymedic' ),
			'id'            => 'footer-2',
			'description'   => esc_html__( 'The footer widget area 2nd column.', 'mymedic' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-title"><h4>',
			'after_title'   => '</h4></div>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 3', 'mymedic' ),
			'id'            => 'footer-3',
			'description'   => esc_html__( 'The footer widget area 3rd column.', 'mymedic' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-title"><h4>',
			'after_title'   => '</h4></div>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 4', 'mymedic' ),
			'id'            => 'footer-4',
			'description'   => esc_html__( 'The footer widget area 4th column.', 'mymedic' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-title"><h4>',
			'after_title'   => '</h4></div>',
		)
	);

}
add_action( 'widgets_init', 'mymedic_sidebars_init' );

/**
 * Register Google fonts.
 *
 * @since  1.0.0
 * @return string
 */
function mymedic_fonts_url() {

	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Droid Serif, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Droid Serif font: on or off', 'mymedic' ) ) {
		$fonts[] = 'Droid Serif:400,700,400italic,700italic';
	}

	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Roboto, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Roboto font: on or off', 'mymedic' ) ) {
		$fonts[] = 'Roboto:400,900italic,900,700italic,700,500italic,500,400italic,300italic,300,100italic,100';
	}

	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Roboto Slab, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Roboto Slab font: on or off', 'mymedic' ) ) {
		$fonts[] = 'Roboto Slab:400,700,300,100';
	}

	/*
	 * Translators: To add an additional character subset specific to your language,
	 * translate this to 'greek', 'cyrillic', 'devanagari' or 'vietnamese'. Do not translate into your own language.
	 */
	$subset = _x( 'no-subset', 'Add new subset (greek, cyrillic, devanagari, vietnamese)', 'mymedic' );

	if ( 'cyrillic' == $subset ) {
		$subsets .= ',cyrillic,cyrillic-ext';
	} elseif ( 'greek' == $subset ) {
		$subsets .= ',greek,greek-ext';
	} elseif ( 'devanagari' == $subset ) {
		$subsets .= ',devanagari';
	} elseif ( 'vietnamese' == $subset ) {
		$subsets .= ',vietnamese';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;
}

if ( ! function_exists( 'is_woocommerce_activated' ) ) :
/**
 * Query WooCommerce activation
 *
 * @since  1.0.0
 */
function is_woocommerce_activated() {
	return class_exists( 'woocommerce' ) ? true : false;
}
endif;

if ( ! function_exists( 'is_polylang_activated' ) ) :
/**
 * Query Polylang activation
 *
 * @since  1.0.0
 */
function is_polylang_activated() {
	return function_exists( 'pll_the_languages' ) ? true : false;
}
endif;

/**
 * Custom template tags for this theme.
 */
require trailingslashit( get_template_directory() ) . 'inc/template-tags.php';

/**
 * Enqueue scripts and styles.
 */
require trailingslashit( get_template_directory() ) . 'inc/scripts.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require trailingslashit( get_template_directory() ) . 'inc/extras.php';

/**
 * Require and recommended plugins list.
 */
require trailingslashit( get_template_directory() ) . 'inc/plugins.php';

/**
 * Customizer.
 */
require trailingslashit( get_template_directory() ) . 'admin/customizer-library.php';
require trailingslashit( get_template_directory() ) . 'admin/functions.php';

/**
 * Customizer functions.
 */
require trailingslashit( get_template_directory() ) . 'inc/customizer.php';
require trailingslashit( get_template_directory() ) . 'inc/mods.php';

/**
 * Bootstrap Nav Walker.
 */
require trailingslashit( get_template_directory() ) . 'inc/classes/class_bootstrap_nav_walker.php';

/**
 * We use some part of Hybrid Core to extends our themes.
 *
 * @link  http://themehybrid.com/hybrid-core Hybrid Core site.
 */
require trailingslashit( get_template_directory() ) . 'inc/hybrid/attr.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/breadcrumb-trail.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/theme-layouts.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/entry-views.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/hybrid-media-grabber.php';

/**
 * Load Jetpack compatibility file.
 */
require trailingslashit( get_template_directory() ) . 'inc/jetpack.php';

/**
 * Load WooCommerce compatibility file.
 */
if ( is_woocommerce_activated() ) {
	require trailingslashit( get_template_directory() ) . 'inc/woocommerce/woocommerce.php';
	require trailingslashit( get_template_directory() ) . 'inc/woocommerce/hooks.php';
	require trailingslashit( get_template_directory() ) . 'inc/woocommerce/template-tags.php';
}

/**
 * Load Polylang compatibility file.
 */
if ( ( function_exists( 'is_polylang_activated' ) && ( is_polylang_activated() ) ) ) {
	require trailingslashit( get_template_directory() ) . 'inc/polylang.php';
}

/**
 * ACF fields.
 */
if ( class_exists( 'acf' ) ) {
	require trailingslashit( get_template_directory() ) . 'inc/acf.php';
}

/**
 * Load SiteOrigin page builder compatibility file.
 */
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if ( is_plugin_active( 'siteorigin-panels/siteorigin-panels.php' ) ) {
	require trailingslashit( get_template_directory() ) . 'inc/builder.php';
}

/**
 * Demo importer
 */
require trailingslashit( get_template_directory() ) . 'inc/demo/demo-importer.php';

// MailOptin integration
require get_template_directory() . '/inc/mailoptin.php';
