<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package    MyMedic
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function mymedic_body_classes( $classes ) {

	// Adds a class of multi-author to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'multi-author';
	}

	// remove 'search' since it broke .btn
	$blacklist = array( 'search' );
	$classes = array_diff( $classes, $blacklist );

	return $classes;
}
add_filter( 'body_class', 'mymedic_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the post element.
 * @return array
 */
function mymedic_post_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}

	return $classes;
}
add_filter( 'post_class', 'mymedic_post_classes' );

/**
 * Change the excerpt more string.
 *
 * @since  1.0.0
 * @param  string  $more
 * @return string
 */
function mymedic_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'mymedic_excerpt_more' );

/**
 * Control excerpt length.
 *
 * @since  1.0.0
 */
function mymedic_excerpt_length( $length ) {

	// Change the excerpt length on grid layout
	if ( 'grid' == mymedic_mod( PREFIX . 'archive-layout' ) ) {
		$length = 25;
	}

	return $length;
}
add_filter( 'excerpt_length', 'mymedic_excerpt_length', 999 );

/**
 * Remove theme-layouts meta box on attachment and bbPress post type.
 * Add theme-layouts meta box on Department post type.
 *
 * @since 1.0.0
 */
function mymedic_add_remove_theme_layout_metabox() {
	remove_post_type_support( 'attachment', 'theme-layouts' );

	// bbPress
	remove_post_type_support( 'forum', 'theme-layouts' );
	remove_post_type_support( 'topic', 'theme-layouts' );
	remove_post_type_support( 'reply', 'theme-layouts' );

	// Department | Service | Testimonial
	add_post_type_support( 'department', 'theme-layouts' );
	add_post_type_support( 'service', 'theme-layouts' );
	add_post_type_support( 'jetpack-testimonial', 'theme-layouts' );
}
add_action( 'init', 'mymedic_add_remove_theme_layout_metabox', 11 );

/**
 * Add post type 'post' support for the Simple Page Sidebars plugin.
 *
 * @since  1.0.0
 */
function mymedic_page_sidebar_plugin() {
	if ( class_exists( 'Simple_Page_Sidebars' ) ) {
		add_post_type_support( 'post', 'simple-page-sidebars' );
	}
}
add_action( 'init', 'mymedic_page_sidebar_plugin' );

/**
 * Register custom contact info fields.
 *
 * @since  1.0.0
 * @param  array $contactmethods
 * @return array
 */
function mymedic_contact_info_fields( $contactmethods ) {
	$contactmethods['twitter']     = __( 'Twitter URL', 'mymedic' );
	$contactmethods['facebook']    = __( 'Facebook URL', 'mymedic' );
	$contactmethods['gplus']       = __( 'Google Plus URL', 'mymedic' );
	$contactmethods['instagram']   = __( 'Instagram URL', 'mymedic' );
	$contactmethods['pinterest']   = __( 'Pinterest URL', 'mymedic' );

	// Remove default contacts
	unset( $contactmethods['aim'] );
	unset( $contactmethods['jabber'] );
	unset( $contactmethods['yim'] );

	return $contactmethods;
}
// add_filter( 'user_contactmethods', 'mymedic_contact_info_fields' );

/**
 * Extend archive title
 *
 * @since  1.0.0
 */
function mymedic_extend_archive_title( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = get_the_author();
	}
	return $title;
}
// add_filter( 'get_the_archive_title', 'mymedic_extend_archive_title' );

/**
 * Customize tag cloud widget
 *
 * @since  1.0.0
 */
function mymedic_customize_tag_cloud( $args ) {
	$args['largest']  = 12;
	$args['smallest'] = 12;
	$args['unit']     = 'px';
	$args['number']   = 20;
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'mymedic_customize_tag_cloud' );
// Uncomment this if support WooCommerce
// add_filter( 'woocommerce_product_tag_cloud_widget_args', 'mymedic_customize_tag_cloud' );

/**
 * Modifies the theme layout on attachment pages.
 *
 * @since  1.0.0
 */
function mymedic_mod_theme_layout( $layout ) {

	// Change the layout to Full Width on Attachment page.
	if ( ( is_attachment() && wp_attachment_is_image() )
		|| ( is_page_template( 'page-templates/block.php' ) )
		|| ( is_page_template( 'page-templates/sitemap.php' ) ) ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '1c';
		}
	}

	return $layout;
}
add_filter( 'theme_mod_theme_layout', 'mymedic_mod_theme_layout', 15 );

/**
 * Custom <header> attributes
 */
function mymedic_attr_header( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_header',  'mymedic_attr_header' );

/**
 * Custom <footer> attributes
 */
function mymedic_attr_footer( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_footer', 'mymedic_attr_footer' );

/**
 * Custom <main> attributes
 */
function mymedic_attr_main( $attr ) {
	$attr['id'] = 'content';
	unset( $attr['class'] );
	unset( $attr['role'] );

	if ( isset( $attr['itemprop'] ) ) {
		$attr['itemtype']  = 'http://schema.org/WebPageElement';
		$attr['itemscope'] = 'itemscope';
	}

	return $attr;
}
add_filter( 'hybrid_attr_content', 'mymedic_attr_main' );

/**
 * Custom sidebar attributes
 */
function mymedic_attr_sidebar( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_sidebar', 'mymedic_attr_sidebar' );

/**
 * Custom <nav> attributes
 */
function mymedic_attr_menu( $attr ) {
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_menu', 'mymedic_attr_menu' );

/**
 * Custom site-title
 */
function mymedic_attr_site_title( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_site-title', 'mymedic_attr_site_title' );

/**
 * Custom site-description
 */
function mymedic_attr_site_description( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_site-description', 'mymedic_attr_site_description' );

/**
 * Custom post <article> attributes
 */
function mymedic_attr_post( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_post', 'mymedic_attr_post' );

/**
 * Custom entry-title
 */
function mymedic_attr_entry_title( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-title', 'mymedic_attr_entry_title' );

/**
 * Custom entry-author
 */
function mymedic_attr_entry_author( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-author', 'mymedic_attr_entry_author' );

/**
 * Custom entry-published
 */
function mymedic_attr_entry_published( $attr ) {
	unset( $attr['class'] );
	unset( $attr['content'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-published', 'mymedic_attr_entry_published' );

/**
 * Custom entry-content
 */
function mymedic_attr_entry_content( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-content', 'mymedic_attr_entry_content' );

/**
 * Custom entry-summary
 */
function mymedic_attr_entry_summary( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-summary', 'mymedic_attr_entry_summary' );

/**
 * Custom entry-terms
 */
function mymedic_attr_entry_terms( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-terms', 'mymedic_attr_entry_terms' );

/**
 * Comments
 */
function mymedic_attr_comment( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment', 'mymedic_attr_comment' );

/**
 * Custom comment-author
 */
function mymedic_attr_comment_author( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-author', 'mymedic_attr_comment_author' );

/**
 * Custom comment-published
 */
function mymedic_attr_comment_published( $attr ) {
	unset( $attr['datetime'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-published', 'mymedic_attr_comment_published' );

/**
 * Custom comment-permalink
 */
function mymedic_attr_comment_permalink( $attr ) {
	unset( $attr['href'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-permalink', 'mymedic_attr_comment_permalink' );

/**
 * Custom comment-content
 */
function mymedic_attr_comment_content( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-content', 'mymedic_attr_comment_content' );

/**
 * Remove role="navigation" from the_posts_pagination()
 */
function mymedic_navigation_markup_template( $template ) {
	return str_replace( ' role="navigation"', '', $template );
}
add_filter( 'navigation_markup_template', 'mymedic_navigation_markup_template' );

/**
 * Remove <p> from category, tag, and term description
 * http://www.daretothink.co.uk/blog/remove-p-tags-category-description/
 */
remove_filter( 'term_description', 'wpautop' );

/**
 * Custom Query
 */
function mymedic_tax_page_query( $query ) {

	// tweak for Taxonomy page for showing result
	if ( ! is_admin() && $query->is_main_query() ) {

		// Doctor's Speciality
		if ( is_tax( 'speciality' ) ) {
			$query->set( 'post_type', 'doctor' );
		}
		if ( is_tax( 'jetpack-portfolio-type' ) ) {
			$query->set( 'post_type', 'jetpack-portfolio' );
		}
		if ( is_tax( 'jetpack-portfolio-tag' ) ) {
			$query->set( 'post_type', 'jetpack-portfolio' );
		}

	}

}
add_action( 'pre_get_posts', 'mymedic_tax_page_query' );

/**
 * Maintenance Mode
 * Refr:
 * https://wordpress.org/plugins/simple-maintenance/
 * https://wordpress.org/plugins/slim-maintenance-mode/
 */
function mymedic_maintenance_template_redirect() {

	// bail out if Maintenance Mode not active
	if ( ! mymedic_mod( PREFIX . 'maintenance-mode' ) )
		return;

	if ( ! current_user_can( 'edit_themes' ) || ! is_user_logged_in() ) {
		header( 'HTTP/1.0 503 Service Unavailable' );
		include_once( trailingslashit( get_template_directory() ) . 'maintenance.php' );
		exit();
	}
}
add_action( 'template_redirect', 'mymedic_maintenance_template_redirect' );
